@@ -1,14 +1,17 @@
 package main
 
 import (
+	"context"
 	"flag"
 	"fmt"
 	"log"
 	"net/http"
 	_ "net/http/pprof"
 	"os"
+	"os/signal"
 	"regexp"
 	"strings"
+	"syscall"
 	"time"
 
 	"github.com/ncabatoff/fakescraper"
@@ -179,6 +182,7 @@ func main() {
 			"log debugging information to stdout")
 		showVersion = flag.Bool("version", false,
 			"print version information and exit")
+		removeEmptyGroups = flag.Bool("remove-empty-groups", false, "forget process groups with no processes")
 	)
 	flag.Parse()
 
@@ -240,14 +244,15 @@ func main() {
 
 	pc, err := collector.NewProcessCollector(
 		collector.ProcessCollectorOption{
-			ProcFSPath:       *procfsPath,
-			Children:         *children,
-			Threads:          *threads,
-			GatherSMaps:      *smaps,
-			Namer:            matchnamer,
-			Recheck:          *recheck,
-			RecheckTimeLimit: *recheckTimeLimit,
-			Debug:            *debug,
+			ProcFSPath:        *procfsPath,
+			Children:          *children,
+			Threads:           *threads,
+			GatherSMaps:       *smaps,
+			Namer:             matchnamer,
+			Recheck:           *recheck,
+			RecheckTimeLimit:  *recheckTimeLimit,
+			Debug:             *debug,
+			RemoveEmptyGroups: *removeEmptyGroups,
 		},
 	)
 	if err != nil {
@@ -267,6 +272,9 @@ func main() {
 		return
 	}
 
+	sigs := make(chan os.Signal, 1)
+	signal.Notify(sigs, syscall.SIGTERM, syscall.SIGINT)
+
 	http.Handle(*metricsPath, promhttp.Handler())
 
 	http.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
@@ -279,10 +287,23 @@ func main() {
 			</html>`))
 	})
 	server := &http.Server{Addr: *listenAddress}
+
+	go func() {
+		<-sigs
+		log.Printf("Shutting down the server\n")
+
+		ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+		defer cancel()
+
+		if err := server.Shutdown(ctx); err != nil {
+			log.Fatalf("Server Shutdown Failed: %v", err)
+		}
+	}()
+
 	if err := web.ListenAndServe(server, &web.FlagConfig{
 		WebListenAddresses: &[]string{*listenAddress},
 		WebConfigFile:      tlsConfigFile,
-	}, logger); err != nil {
+	}, logger); err != nil && err != http.ErrServerClosed {
 		log.Fatalf("Failed to start the server: %v", err)
 		os.Exit(1)
 	}
