@@ -156,14 +156,15 @@ type (
 	}
 
 	ProcessCollectorOption struct {
-		ProcFSPath       string
-		Children         bool
-		Threads          bool
-		GatherSMaps      bool
-		Namer            common.MatchNamer
-		Recheck          bool
-		RecheckTimeLimit time.Duration
-		Debug            bool
+		ProcFSPath        string
+		Children          bool
+		Threads           bool
+		GatherSMaps       bool
+		Namer             common.MatchNamer
+		Recheck           bool
+		RecheckTimeLimit  time.Duration
+		Debug             bool
+		RemoveEmptyGroups bool
 	}
 
 	NamedProcessCollector struct {
@@ -188,7 +189,7 @@ func NewProcessCollector(options ProcessCollectorOption) (*NamedProcessCollector
 	fs.GatherSMaps = options.GatherSMaps
 	p := &NamedProcessCollector{
 		scrapeChan: make(chan scrapeRequest),
-		Grouper:    proc.NewGrouper(options.Namer, options.Children, options.Threads, options.Recheck, options.RecheckTimeLimit, options.Debug),
+		Grouper:    proc.NewGrouper(options.Namer, options.Children, options.Threads, options.Recheck, options.RecheckTimeLimit, options.Debug, options.RemoveEmptyGroups),
 		source:     fs,
 		threads:    options.Threads,
 		smaps:      options.GatherSMaps,
